# user_code.py
from ambientagi.services.agent_service import AmbientAgentService

# 1) Create a new agent
service = AmbientAgentService(api_key="")

# 2) Launch the WebUI with that agent_id
webui_agent = service.add_webui_agent(agent_id="6e62aece-630b-4596-a9a9-5ed896ff4bbd")
webui_agent.launch()  # This will parse command line args or just run on default IP/port



# test_headless_false.py

import asyncio

from ambientagi.services.agent_service import AmbientAgentService


async def main():
    service = AmbientAgentService(api_key="")  # your OpenAI key

    agent = service.create_agent(
        agent_name="VisibleAgent",
        wallet_address="0xVISIBLE",
        description="Open Google and report the title",
    )

    browser_agent = service.create_browser_agent(agent_id=agent["agent_id"])

    result = await browser_agent.run_task(
        model="gpt-4o",
        task="Go to https://google.com and report the page title.",
    )

    print("\n[VISIBLE RESULT]:", result.final_result())


if __name__ == "__main__":
    asyncio.run(main())



from typing import Any, Dict, Optional

from browser_use import Agent
from browser_use.browser.browser import Browser, BrowserConfig
from browser_use.browser.context import BrowserContextConfig
from langchain_openai import ChatOpenAI
from pydantic import SecretStr


class BrowserAgent:
    def __init__(
        self,
        agent: dict,
        api_key: Optional[str] = None,
        browser_config: Optional[Dict[str, Any]] = None,
        context_config: Optional[Dict[str, Any]] = None,
    ):
        self.name = agent["agent_name"]
        self.wallet_address = agent["wallet_address"]
        self.task = agent["description"]

        self.api_key = api_key  # ✅ store the passed-in user key

        self.browser_config = BrowserConfig(**(browser_config or {}))
        self.context_config = BrowserContextConfig(**(context_config or {}))
        self.browser_config.new_context_config = self.context_config

    async def run_task(self, task: Optional[str] = None, model: str = "gpt-4o"):
        task = task or self.task

        browser = Browser(config=self.browser_config)

        agent = Agent(
            task=task,
            llm=ChatOpenAI(
                model=model,
                api_key=SecretStr(self.api_key) if self.api_key else None,
            ),
            browser=browser,
            browser_context=await browser.new_context(config=self.context_config),
        )
        return await agent.run()



# test_browser_firefox.py

import asyncio

from ambientagi.services.agent_service import AmbientAgentService


async def main():
    service = AmbientAgentService(api_key="sk-...")  # your OpenAI API key

    agent = service.create_agent(
        agent_name="FirefoxAgent",
        wallet_address="0xFIREFOX",
        description="Search 'AmbientAGI GitHub' and return the repo link.",
    )

    browser_agent = service.create_browser_agent(
        agent_id=agent["agent_id"],
        browser_config={
            "browser_class": "firefox",  # ✅ key line for Firefox
            "headless": False,
            "new_context_config": {
                "window_width": 1200,
                "window_height": 800,
            },
        },
    )

    result = await browser_agent.run_task(
        model="gpt-4o",
        task="Search 'AmbientAGI GitHub' and return the repository link.",
    )

    print("\n[FIREFOX RESULT]:", result.final_result())


if __name__ == "__main__":
    asyncio.run(main())



from swarms.tools.base_tool import BaseTool
from swarms.tools.cohere_func_call_schema import (CohereFuncSchema,
                                                  ParameterDefinition)
from swarms.tools.json_utils import base_model_to_json
from swarms.tools.openai_func_calling_schema_pydantic import \
    OpenAIFunctionCallSchema as OpenAIFunctionCallSchemaBaseModel
from swarms.tools.openai_tool_creator_decorator import tool
from swarms.tools.py_func_to_openai_func_str import (
    Function, ToolFunction, get_load_param_if_needed_function,
    get_openai_function_schema_from_func, get_parameters, get_required_params,
    load_basemodels_if_needed)
from swarms.tools.pydantic_to_json import (_remove_a_key,
                                           base_model_to_openai_function,
                                           multi_base_model_to_openai_function)
from swarms.tools.tool_registry import ToolStorage, tool_registry
from swarms.tools.tool_utils import scrape_tool_func_docs, tool_find_by_name

__all__ = [
    "scrape_tool_func_docs",
    "tool_find_by_name",
    "_remove_a_key",
    "base_model_to_openai_function",
    "multi_base_model_to_openai_function",
    "OpenAIFunctionCallSchemaBaseModel",
    "get_openai_function_schema_from_func",
    "load_basemodels_if_needed",
    "get_load_param_if_needed_function",
    "get_parameters",
    "get_required_params",
    "Function",
    "ToolFunction",
    "tool",
    "BaseTool",
    "CohereFuncSchema",
    "ParameterDefinition",
    "ToolStorage",
    "tool_registry",
    "base_model_to_json",
]



from ambientagi.services.agent_service import AmbientAgentService

print("DEPLOY YOUR AGENT ON A BLOCKCHAIN NETWORK - ETHEREUM")
funder_private_key = input("Enter your private key: ")
amount_eth = input("Enter the amount of ETH to deploy: ")
token_name = input("Enter the name of the token: ")
symbol = input("Enter the symbol of the token: ")
image_path = input("Enter the path to the image of the token: ")

ethereum_agent = AmbientAgentService(api_key="").add_blockchain(
    "f652e0b2-bbd0-48bd-a579-662e1c7120f5"
)
token_response = ethereum_agent.create_eth_token(
    privateKey="30fdd34373cc5d303e545df8ff32bceeee320825543e14abc63f1d43b0c3921a",
    token_name="Browsy",
    symbol="BRWSY",
    decimals=18,
    buy_value_eth=0.01,
    image_path="browsy.png",
)
print(token_response)



# headless_true.py

import asyncio

from ambientagi.services.agent_service import AmbientAgentService


async def main():
    service = AmbientAgentService(api_key="")  # your OpenAI key

    agent = service.create_agent(
        agent_name="HeadlessBot",
        wallet_address="0xBOT",
        description="Get latest news headline from CNN",
    )

    # ✅ Consistent usage of create_browser_agent with overrides
    browser_agent = service.create_browser_agent(
        agent_id=agent["agent_id"],
        browser_config={
            "headless": True,
            "new_context_config": {
                "window_width": 1280,
                "window_height": 900,
            },
        },
    )

    result = await browser_agent.run_task(
        model="gpt-4o",
        task="Go to cnn.com and return the top headline on the homepage.",
    )

    print("\n[HEADLESS RESULT]:", result.final_result())


if __name__ == "__main__":
    asyncio.run(main())
